# eric7.Plugins.VcsPlugins.vcsPySvn.SvnPropDelDialog

Module implementing a dialog to enter the data for a new property.

### Global Attributes

None

### Classes

SvnPropDelDialog | Class implementing a dialog to enter the data for a new property.

### Functions

None

## SvnPropDelDialog

Class implementing a dialog to enter the data for a new property.

### Derived from

QDialog, Ui_SvnPropDelDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnPropDelDialog | Constructor
getData | Public slot used to retrieve the data entered into the dialog.
on_propNameEdit_textChanged | Private method used to enable/disable the OK-button.

### Static Methods

None

#### SvnPropDelDialog (Constructor)

SvnPropDelDialog(recursive, parent=None)

Constructor

recursive (bool)
  flag indicating a recursive set is requested
parent (QWidget)
  parent widget

#### SvnPropDelDialog.getData

getData()

Public slot used to retrieve the data entered into the dialog.

Return:
  tuple of two values giving the property name and a flag indicating, that this property should be applied recursively.

Return Type:
  tuple of (str, bool)

#### SvnPropDelDialog.on_propNameEdit_textChanged

on_propNameEdit_textChanged(text)

Private method used to enable/disable the OK-button.

text (str)
  text of the property name edit

Up